@@ -6,16 +6,16 @@ use warnings;
 use Math::GSL::Machine qw/:all/;
 use Math::GSL::Const qw/:all/;
 use Math::GSL::Errno qw/:all/;
+use Math::GSL::Vector qw/:file/;
 use Carp qw/croak/;
 use Config;
-use Data::Dumper;
 use Test::More;
-use Scalar::Util qw/looks_like_number/;
 our @EXPORT = qw();
 our @EXPORT_OK = qw( ok_similar ok_status  is_similar
                      is_similar_relative verify verify_results 
                      $GSL_MODE_DEFAULT $GSL_PREC_DOUBLE
                      $GSL_PREC_SINGLE $GSL_PREC_APPROX
+                     is_windows gsl_inf gsl_fopen gsl_fclose gsl_nan
                    );
 
 our %EXPORT_TAGS = ( 
@@ -24,15 +24,15 @@ our %EXPORT_TAGS = (
 
 our ($GSL_PREC_DOUBLE, $GSL_PREC_SINGLE, $GSL_PREC_APPROX ) = 0..2;
 our $GSL_MODE_DEFAULT = $GSL_PREC_DOUBLE;
-our $VERSION = '0.06_03';
+our $VERSION = '0.09_01';
 
 =head1 NAME
 
-Math::GSL - Perl interface to the  GNU Scientific Library (GSL) using SWIG
+Math::GSL - Perl interface to the  GNU Scientific Library (GSL) 
 
 =head1 VERSION
 
-Version 0.06_03
+Version 0.09_01
 
 =cut
 
@@ -70,7 +70,7 @@ intuitive (but slightly slower) object-oriented interface.
     Math::GSL::FFT              - Fast Fourier Transform
     Math::GSL::Fit              - Curve Fitting
     Math::GSL::Heapsort         - Sorting Heaps
-    Math::GSL::Histograma       - Histograms
+    Math::GSL::Histogram        - Histograms
     Math::GSL::Histogram2D      - 2D Histograms
     Math::GSL::Integration      - Numerical Integration
     Math::GSL::Interp           - Interpolation
@@ -78,7 +78,6 @@ intuitive (but slightly slower) object-oriented interface.
     Math::GSL::Machine          - Machine Specific Information
     Math::GSL::Matrix           - NxM Matrices
     Math::GSL::Min              - Minimization
-    Math::GSL::Mode             - GSL Precision Modes
     Math::GSL::Monte            - Monte Carlo Integrations
     Math::GSL::Multifit         - Multivariable Fitting
     Math::GSL::Multimin         - Multivariable Minimization
@@ -110,8 +109,8 @@ Jonathan Leto, C<< <jonathan@leto.net> >> and Thierry Moisan C<< <thierry.moisan
 
 =head1 BUGS
 
-This software is still in active development, we appreciate your detailed bug reports.
-Please report any bugs or feature requests to the authors directly.
+This software is still in active development, we appreciate your detailed bug reports and
+documentation patches. Please report any bugs or feature requests to the authors directly.
 
 
 =head1 SUPPORT
@@ -156,6 +155,12 @@ L<http://git.or.cz>.
 
 =head1 ACKNOWLEDGEMENTS
 
+Thanks to PDX.pm, The Perl Foundation and everyone at Google who makes
+the Summer of Code happen each year. You rock.
+
+=head1 DEDICATION
+
+This Perl module is dedicated in memory of Nick Ing-Simmons.
 
 =head1 COPYRIGHT & LICENSE
 
@@ -178,16 +183,16 @@ sub subsystems
 {
     return sort qw/
         Diff         Machine      Statistics
-        Block        Eigen        Matrix        Poly 
+        Eigen        Matrix       Poly 
         BSpline      Errno        PowInt        
         CBLAS        FFT          Min           IEEEUtils
-        CDF          Fit          Mode          QRNG
+        CDF          Fit          QRNG
         Chebyshev    Monte        RNG           Vector
         Heapsort     Multifit     Randist       Roots     
         Combination  Histogram    Multimin      Wavelet
         Complex      Histogram2D  Multiroots    Wavelet2D
         Const        Siman        Sum           Sys
-        Integration  NTuple       Sort                  
+        NTuple       Integration  Sort                  
         DHT          Interp       ODEIV         SF 
         Deriv        Linalg       Permutation   Spline
     /;
@@ -223,7 +228,8 @@ sub is_similar {
 }
 sub ok_status {
     my ($got, $expected) = @_;
-    ok( $got == $expected, gsl_strerror($expected) );
+    $expected ||= $GSL_SUCCESS;
+    ok( $got == $expected, gsl_strerror(int($got)) );
 }
 sub ok_similar {
     my ($x,$y, $msg, $eps) = @_;
@@ -263,7 +269,6 @@ sub verify_results
                 printf "difference : %.18g\n", $res;
                 printf "unexpected error of %.18g\n", $res-$eps if ($res-$eps>0);
             }
-
             if ($x =~ /nan|inf/i) {
                     ok( $expected eq $x, "'$expected'?='$x'" );
             } else { 
@@ -295,11 +300,36 @@ sub verify
     }
 }
 
+sub gsl_inf
+{ 
+    is_windows() ?  unpack 'd', scalar reverse pack 'H*', '7FF0000000000000' 
+                 : q{inf}
+}
+sub gsl_nan
+{
+    is_windows() ? unpack 'd', scalar reverse pack 'H*', '7FF8000000000000' 
+                 : q{nan}
+             }
+sub gsl_fopen
+{
+    my ($file, $mode) = @_;
+    $mode .= '+b' if (is_windows() and $mode !~ /\+b/);
+    return Math::GSL::Vector::fopen($file, $mode);
+}
+
+sub gsl_fclose
+{
+    my $file = shift;
+    return Math::GSL::Vector::fclose($file);
+}
+
+
 sub _dump_result($)
 {
     my $r=shift;
     printf "result->err: %.18g\n", $r->{err};
     printf "result->val: %.18g\n", $r->{val};
 }
+sub is_windows() { $^O =~ /MSWin32/i }
 
 42;
