@@ -249,4 +249,11 @@ my $filip_y = [0.8116, 0.9072, 0.9052, 0.9039, 0.8053, 0.8377,
     @got = gsl_blas_ddot($r, $r);
     ok(is_similar_relative($got[1], $expected_chisq, 10**-7), "filip gsl_fit_wmultilinear residuals") ;
 }
+
+sub GSL_MULTIFIT_FSOLVER_ALLOC : Tests {
+   local $TODO = "the only gsl_multifit_fsolver_type is commented out in gsl_multifit_nlin.h";
+   ok(0);
+   #my $fsolver = gsl_multifit_fsolver_alloc($gsl_multifit_fsolver_gradient, 100, 3);
+   #isa_ok($fsolver, 'Math::GSL::Multifit');
+}
 1;
